@@ -86,7 +86,7 @@ new WafwebaclToCloudFront(this, "test-wafwebacl-cloudfront", new WafwebaclToClou
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|existingCloudFrontWebDistribution|[`cloudfront.Distribution`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.Distribution.html)|The existing CloudFront instance that will be protected with the WAF web ACL. *Note that a WAF web ACL can only be added to a configured CloudFront, so this construct only accepts an existing CloudFrontWebDistribution and does not accept cloudfrontProps.*|
+|existingCloudFrontWebDistribution|[`cloudfront.Distribution`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.Distribution.html)|The existing CloudFront instance that will be protected with the WAF web ACL. *Note that a WAF web ACL can only be added to a configured CloudFront, so this construct only accepts an existing Distribution and does not accept cloudfrontProps.*|
 |existingWebaclObj?|[`waf.CfnWebACL`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-wafv2.CfnWebACL.html)|Existing instance of a WAF web ACL, an error will occur if this and props is set.|
 |webaclProps?|[`waf.CfnWebACLProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-wafv2.CfnWebACLProps.html)|Optional user-provided props to override the default props for the AWS WAF web ACL. To use a different collection of managed rule sets, specify a new rules property. Use our [`wrapManagedRuleSet(managedGroupName: string, vendorName: string, priority: number)`](../core/lib/waf-defaults.ts) function from core to create an array entry from each desired managed rule set.|
 
@@ -139,6 +139,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudfront
@@ -162,7 +164,7 @@ class WafwebaclToCloudFront(
         *,
         existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
         existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps] = None,
+        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -174,6 +176,10 @@ class WafwebaclToCloudFront(
         :access: public
         :summary: Constructs a new instance of the WafwebaclToCloudFront class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(WafwebaclToCloudFront.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WafwebaclToCloudFrontProps(
             existing_cloud_front_web_distribution=existing_cloud_front_web_distribution,
             existing_webacl_obj=existing_webacl_obj,
@@ -208,7 +214,7 @@ class WafwebaclToCloudFrontProps:
         *,
         existing_cloud_front_web_distribution: aws_cdk.aws_cloudfront.Distribution,
         existing_webacl_obj: typing.Optional[aws_cdk.aws_wafv2.CfnWebACL] = None,
-        webacl_props: typing.Optional[aws_cdk.aws_wafv2.CfnWebACLProps] = None,
+        webacl_props: typing.Optional[typing.Union[aws_cdk.aws_wafv2.CfnWebACLProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param existing_cloud_front_web_distribution: The existing CloudFront instance that will be protected with the WAF web ACL. This construct changes the CloudFront distribution by directly manipulating the CloudFormation output, so this must be the Construct and cannot be changed to the Interface (IDistribution)
@@ -219,6 +225,11 @@ class WafwebaclToCloudFrontProps:
         '''
         if isinstance(webacl_props, dict):
             webacl_props = aws_cdk.aws_wafv2.CfnWebACLProps(**webacl_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(WafwebaclToCloudFrontProps.__init__)
+            check_type(argname="argument existing_cloud_front_web_distribution", value=existing_cloud_front_web_distribution, expected_type=type_hints["existing_cloud_front_web_distribution"])
+            check_type(argname="argument existing_webacl_obj", value=existing_webacl_obj, expected_type=type_hints["existing_webacl_obj"])
+            check_type(argname="argument webacl_props", value=webacl_props, expected_type=type_hints["webacl_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "existing_cloud_front_web_distribution": existing_cloud_front_web_distribution,
         }
